intelmq.bots.experts.maxmind_geoip package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.maxmind_geoip package

## Submodules

## intelmq.bots.experts.maxmind_geoip.expert module

This product includes GeoLite2 data created by MaxMind, available from <a href=”http://www.maxmind.com”>http://www.maxmind.com</a>.

`intelmq.bots.experts.maxmind_geoip.expert.` `BOT`

  alias of `intelmq.bots.experts.maxmind_geoip.expert.GeoIPExpertBot`

class `intelmq.bots.experts.maxmind_geoip.expert.` `GeoIPExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Add geolocation information from a local MaxMind database to events (country, city, longitude, latitude)

  `database`: str = '/opt/intelmq/var/lib/bots/maxmind_geoip/GeoLite2-City.mmdb'
  `init`()
  `license_key`: str = '<insert Maxmind license key>'
  `overwrite`: bool = False
  `process`()
  classmethod `run`(parsed_args=None)
  classmethod `update_database`()
  `use_registered`: bool = False

## Module contents